# Contribution Guides

This page provides guides on many of the plugin contribution patterns.
Each provides a general overview of the purpose of the contribution and
an example implementation. For details on the type and meaning of each
field in a specific contribution, See the
[contributions reference](./contributions)


```{include} _npe2_readers_guide.md
```
----------------

```{include} _npe2_writers_guide.md
```
----------------

```{include} _npe2_widgets_guide.md
```
----------------

```{include} _npe2_sample_data_guide.md
```
----------------

```{include} _layer_data_guide.md
```
